@@ -1,10 +1,10 @@
 use strict;
 use warnings;
-package Task::Kensho::Scalability;
-# git description: v0.37-33-gd4b16f5
-$Task::Kensho::Scalability::VERSION = '0.38';
+package Task::Kensho::Scalability; # git description: v0.38-58-g492cdd9
 # ABSTRACT: A Glimpse at an Enlightened Perl: Scalability
 
+our $VERSION = '0.39';
+
 __END__
 
 =pod
@@ -17,7 +17,7 @@ Task::Kensho::Scalability - A Glimpse at an Enlightened Perl: Scalability
 
 =head1 VERSION
 
-version 0.38
+version 0.39
 
 =head1 SYNOPSIS
 
@@ -88,6 +88,11 @@ The C<cpanm> client requires interactive mode to be enabled for this to work:
 
     cpanm --interactive Task::Kensho::Scalability
 
+=head1 SEE ALSO
+
+L<http://www.enlightenedperl.org/>,
+L<Perl::Dist::Strawberry|Perl::Dist::Strawberry>
+
 =head1 BUGS AND LIMITATIONS
 
 This list is by no means comprehensive of the "Good" Modules on CPAN.
@@ -99,25 +104,18 @@ starting place on the road to Enlightened Perl programming.
 Please report any bugs or feature requests to
 L<https://github.com/EnlightenedPerlOrganisation/task-kensho/issues>.
 
-=head1 SEE ALSO
+bugs may be submitted through L<https://github.com/EnlightenedPerlOrganisation/task-kensho/issues>.
 
-L<http://www.enlightenedperl.org/>,
-L<Perl::Dist::Strawberry|Perl::Dist::Strawberry>
+There is also an irc channel available for users of this distribution, at
+L<C<#epo> on C<irc.perl.org>|irc://irc.perl.org/#epo>.
 
 =head1 AUTHOR
 
 Chris Prather <chris@prather.org>
 
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2008 by Chris Prather.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =head1 CONTRIBUTORS
 
-=for stopwords Karen Etheridge Leo Lapworth Chris Nehren
+=for stopwords Karen Etheridge Leo Lapworth Chris Nehren Rick Leir
 
 =over 4
 
@@ -133,6 +131,17 @@ Leo Lapworth <leo@cuckoo.org>
 
 Chris Nehren <apeiron@cpan.org>
 
+=item *
+
+Rick Leir <rleir@leirtech.com>
+
 =back
 
+=head1 COPYRIGHT AND LICENCE
+
+This software is copyright (c) 2008 by Chris Prather.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
